The input list with the name of the list item added in a new column
for all data frames.
Arguments
in_list
The list to work on. Must have names.
column_name
The name of the column to add to the data frames.
skip_non_df
Whether to skip items that are not data frames.
Details
With `column_name` you can specify the name the new columns in the
data.frames should have. The default is `.group`.
Using `skip_non_df` you can specify to omit elements from the input list
that are not data frames. If FALSE an error will be thrown if elements are
present that are not data frames. If TRUE (the default) then items that are
not data frames will be ignored and remain unchanged.